@@ -3,6 +3,7 @@ import logging
 from object import PyObject, PyObjects
 from logic_utils import ticks_to_datetime
 import pandas as pd
+from datetime import datetime
 
 logger = logging.getLogger("PyTabular")
 
@@ -18,8 +19,16 @@ class PyPartition(PyObject):
     def __init__(self, object, table) -> None:
         super().__init__(object)
         self.Table = table
+        self._display.add_row("Mode", str(self._object.Mode))
+        self._display.add_row("State", str(self._object.State))
+        self._display.add_row(
+            "SourceType", str(self._object.SourceType), end_section=True
+        )
+        self._display.add_row(
+            "RefreshedTime", self.Last_Refresh().strftime("%m/%d/%Y, %H:%M:%S")
+        )
 
-    def Last_Refresh(self):
+    def Last_Refresh(self) -> datetime:
         """Queries `RefreshedTime` attribute in the partition and converts from C# Ticks to Python datetime
 
         Returns:
@@ -33,7 +42,7 @@ class PyPartition(PyObject):
         Returns:
             pd.DataFrame: Returns pandas dataframe with some refresh details
         """
-        return self.Table.Model.Refresh(self._object, *args, **kwargs)
+        return self.Table.Model.Refresh(self, *args, **kwargs)
 
 
 class PyPartitions(PyObjects):
